.. DataRobot Python Package documentation master file, created by
   sphinx-quickstart on Mon Mar 16 10:50:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

DataRobot Python Package
========================

.. toctree::
   :maxdepth: 2

   setup/getting_started.rst
   setup/configuration.rst
   entities/quickstart.rst
   entities/project.rst
   entities/datetime_partition.rst
   entities/time_series.rst
   entities/blueprint.rst
   entities/model.rst
   entities/job.rst
   entities/model_job.rst
   entities/predict_job.rst
   entities/prediction_explanations.rst
   entities/prime.rst
   entities/rating_table.rst
   entities/training_predictions.rst
   entities/monotonic_constraints.rst
   entities/database_connectivity.rst
   entities/model_recommendation.rst
   api/index.rst
   examples/index.rst
   CHANGES.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
